TinyMCE and Filebrowsing — MassMedia v0.8.5 documentation

MassMedia v0.8.5 documentation

# TinyMCE and Filebrowsing

- Table of Contents
- index
  modules
  next
  previous

# TinyMCE and Filebrowsing

Add to project settings:

    TINYMCE_FILEBROWSER = True

In TINYMCE_DEFAULT_CONFIG add:

    extended_valid_elements "-p[class|style]," and "-div[class|style],"

Create two URL definitions:

    url(r'^browse/', 'massmedia.views.browse', name="fb_browse"),
    url(r'^tinymcepopup$', 'massmedia.views.tinymcepopup_url', name="tinymcepopupurl"),